Simple test
------------

Displays annotations, examples relative to SwitchRound widget or as freeform.

.. literalinclude:: ../examples/displayio_annotation_simpletest.py
    :caption: examples/displayio_annotation_simpletest.py
    :linenos:
